suppressPackageStartupMessages(library(stars))
bcsd_obs
L7_ETMs
if (require(starsdata, quietly = TRUE)) {
	print(stars_sentinel2)
}
